@@ -35,6 +35,8 @@ def test():
     suite.addTests(tests)
     tests = unittest.TestLoader().loadTestsFromTestCase(Analysis.TestCrossSectionValueHolder)
     suite.addTests(tests)
+    tests = unittest.TestLoader().loadTestsFromTestCase(Analysis.TestSecurityValues)
+    suite.addTests(tests)
     tests = unittest.TestLoader().loadTestsFromTestCase(Analysis.TestTransformer)
     suite.addTest(tests)
     tests = unittest.TestLoader().loadTestsFromTestCase(Analysis.TechnicalAnalysis.TestStatelessTechnicalAnalysis)
@@ -55,8 +57,6 @@ def test():
     suite.addTests(tests)
     tests = unittest.TestLoader().loadTestsFromTestCase(Math.Distributions.TestDistribution)
     suite.addTests(tests)
-    tests = unittest.TestLoader().loadTestsFromTestCase(Math.TestErrorFunction)
-    suite.addTests(tests)
     tests = unittest.TestLoader().loadTestsFromTestCase(PricingEngines.TestBlackFormula)
     suite.addTests(tests)
     tests = unittest.TestLoader().loadTestsFromTestCase(PricingEngines.TestSabrFormula)
